package com.zeocollect;

import android.util.Log;

import androidx.annotation.NonNull;

import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.module.annotations.ReactModule;
import com.zeotap.collect.Collect;

@ReactModule(name = ZeoCollectModule.NAME)
public class ZeoCollectModule extends ReactContextBaseJavaModule {
    public static final String NAME = "ZeoCollect";

    String TAG = "Zeotap_App: ";
    Collect collect;

    public ZeoCollectModule(ReactApplicationContext reactContext) {
        super(reactContext);
        collect = Collect.getInstance();
    }

    @Override
    @NonNull
    public String getName() {
        return NAME;
    }

    @ReactMethod
    public void setEventNameProperties(String eventName) {
        Log.d("teest", "called from setEvent inside module");
        Log.d("teest", collect.getClass().toString());
        Log.d("teest", collect == null ? "collect is null" : "collect is not null" + collect.getClass().toString());
        Log.d(TAG, "setEventProperties: EventName = " + eventName);
        collect.setEventProperties(eventName);
    }

    @ReactMethod
    public void setEventProperties(String eventName, ReadableMap eventProp) {
        Log.d(TAG, "setEventProperties: EventName = " + eventName + " EventProperty = " + eventProp.toHashMap().toString());
        collect.setEventProperties(eventName, eventProp.toHashMap());
    }

    @ReactMethod
    public void setInstantEventNameProperties(String eventName) {
        Log.d(TAG, "setInstantEventProperties: EventName = " + eventName);
        collect.setInstantEventProperties(eventName);
    }

    @ReactMethod
    public void setInstantEventProperties(String eventName, ReadableMap eventProp) {
        Log.d(TAG, "setInstantEventProperties: EventName = " + eventName + " EventProperty = " + eventProp.toHashMap().toString());
        collect.setInstantEventProperties(eventName, eventProp.toHashMap());
    }

    @ReactMethod
    public void setUserIdentities(ReadableMap userProp) {
        Log.d(TAG, "setUserIdentities: UserIdentities = " + userProp.toHashMap().toString());
        collect.setUserIdentities(userProp.toHashMap());
    }

    @ReactMethod
    public void setUserProperties(ReadableMap userProp) {
        Log.d(TAG, "setUserProperties: UserProperties = " + userProp.toHashMap().toString());
        collect.setUserProperties(userProp.toHashMap());
    }

    @ReactMethod
    public void setPageProperties(ReadableMap properties) {
        Log.d(TAG, "setPageProperties: PageProperty = " + properties.toHashMap().toString());
        collect.setPageProperties(properties.toHashMap());
    }

    @ReactMethod
    public void unsetUserIdentities() {
        Log.d(TAG, "unsetUserIdentities");
        collect.unsetUserIdentities();
    }

    @ReactMethod
    public void deInitiate() {
        Log.d(TAG, "pauseCollection");
        collect.pauseCollection();
    }

    @ReactMethod
    public void reInitialize() {
        Log.d(TAG, "resumeCollection");
        collect.resumeCollection();
    }

    @ReactMethod
    public void setConsent(ReadableMap consent) {
        Log.d(TAG, "setConsent: ConsentProperty = " + consent.toHashMap().toString());
        collect.setConsent(consent.toHashMap());
    }

    @ReactMethod
    public void addAskForConsentListener(Callback cb) {
        collect.listenToAskForConsent((data) -> cb.invoke());
    }

    @ReactMethod
    public void getZI(Callback cb) {
        String zi = collect.getZI();
        cb.invoke(zi);
    }

    @ReactMethod
    public void resetZI() {
        collect.resetZI();
    }
}
